"use strict";
var __extends = (this && this.__extends) || (function () {
    var extendStatics = function (d, b) {
        extendStatics = Object.setPrototypeOf ||
            ({ __proto__: [] } instanceof Array && function (d, b) { d.__proto__ = b; }) ||
            function (d, b) { for (var p in b) if (Object.prototype.hasOwnProperty.call(b, p)) d[p] = b[p]; };
        return extendStatics(d, b);
    };
    return function (d, b) {
        extendStatics(d, b);
        function __() { this.constructor = d; }
        d.prototype = b === null ? Object.create(b) : (__.prototype = b.prototype, new __());
    };
})();
Object.defineProperty(exports, "__esModule", { value: true });
exports.ValidationError = exports.compile = exports.compileFromFile = exports.DEFAULT_OPTIONS = void 0;
var fs_1 = require("fs");
var lodash_1 = require("lodash");
var formatter_1 = require("./formatter");
var generator_1 = require("./generator");
var normalizer_1 = require("./normalizer");
var optimizer_1 = require("./optimizer");
var parser_1 = require("./parser");
var utils_1 = require("./utils");
var validator_1 = require("./validator");
var util_1 = require("util");
var linker_1 = require("./linker");
exports.DEFAULT_OPTIONS = {
    bannerComment: "/* tslint:disable */\n/**\n* This file was automatically generated by json-schema-to-typescript.\n* DO NOT MODIFY IT BY HAND. Instead, modify the source JSONSchema file,\n* and run json-schema-to-typescript to regenerate this file.\n*/",
    enableConstEnums: true,
    format: true,
    ignoreMinAndMaxItems: false,
    strictIndexSignatures: false,
    style: {
        bracketSpacing: false,
        printWidth: 120,
        semi: true,
        singleQuote: false,
        tabWidth: 2,
        trailingComma: 'none',
        useTabs: false
    },
    unreachableDefinitions: false,
    unknownAny: true
};
function compileFromFile(filename, options) {
    if (options === void 0) { options = exports.DEFAULT_OPTIONS; }
    var contents = utils_1.Try(function () { return fs_1.readFileSync(filename); }, function () {
        throw new ReferenceError("Unable to read file \"" + filename + "\"");
    });
    var schema = utils_1.Try(function () { return JSON.parse(contents.toString()); }, function () {
        throw new TypeError("Error parsing JSON in file \"" + filename + "\"");
    });
    return compile(schema, utils_1.stripExtension(filename), options);
}
exports.compileFromFile = compileFromFile;
function compile(schema, name, options) {
    if (options === void 0) { options = {}; }
    var _options = lodash_1.merge({}, exports.DEFAULT_OPTIONS, options);
    var start = Date.now();
    function time() {
        return "(" + (Date.now() - start) + "ms)";
    }
    var errors = validator_1.validate(schema, name);
    if (errors.length) {
        errors.forEach(function (_) { return utils_1.error(_); });
        throw new ValidationError();
    }
    if (process.env.VERBOSE) {
        utils_1.log('green', 'validator', time(), '✅ No change');
    }
    var linked = linker_1.link(schema);
    if (process.env.VERBOSE) {
        utils_1.log('green', 'linker', time(), '✅ No change');
    }
    var normalized = normalizer_1.normalize(linked, name, _options);
    if (process.env.VERBOSE) {
        if (util_1.isDeepStrictEqual(linked, normalized)) {
            utils_1.log('yellow', 'normalizer', time(), '✅ No change');
        }
        else {
            utils_1.log('yellow', 'normalizer', time(), '✅ Result:', normalized);
        }
    }
    var parsed = parser_1.parse(normalized, _options);
    utils_1.log('blue', 'parser', time(), '✅ Result:', parsed);
    var optimized = optimizer_1.optimize(parsed);
    if (process.env.VERBOSE) {
        if (util_1.isDeepStrictEqual(parsed, optimized)) {
            utils_1.log('cyan', 'optimizer', time(), '✅ No change');
        }
        else {
            utils_1.log('cyan', 'optimizer', time(), '✅ Result:', optimized);
        }
    }
    var generated = generator_1.generate(optimized, _options);
    utils_1.log('magenta', 'generator', time(), '✅ Result:', generated);
    var formatted = formatter_1.format(generated, _options);
    utils_1.log('white', 'formatter', time(), '✅ Result:', formatted);
    return formatted;
}
exports.compile = compile;
var ValidationError = /** @class */ (function (_super) {
    __extends(ValidationError, _super);
    function ValidationError() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    return ValidationError;
}(Error));
exports.ValidationError = ValidationError;
//# sourceMappingURL=index.js.map